---
hide:
  - navigation
  - toc
---

[:material-notebook-edit:](#){: #__notebook-edit .source-link title="Edit notebook page"}
[:material-language-python:](#){: #__notebook-py-gist .source-link title="Load Python code from source"}
[:material-language-markdown:](#){: #__notebook-md-gist .source-link title="Load page from Markdown source"}
<h1>Notebook</h1>

---

<div id="__notebook-render"></div>

<div id="__notebook-source" class="notebook hidden">
<textarea id="__notebook-input"></textarea>
<button id="__notebook-submit" title="Submit">Submit</button>
<button id="__notebook-cancel" title="Cancel">Cancel</button>
</div>
